@@ -2,7 +2,7 @@
  * Provides basic compose code shared between standard and dynamic displays.
  *
  * @author     Michael Slusarz <slusarz@horde.org>
- * @copyright  2014 Horde LLC
+ * @copyright  2014-2015 Horde LLC
  * @license    GPL-2 (http://www.horde.org/licenses/gpl)
  */
 
@@ -131,7 +131,7 @@ var ImpComposeBase = {
                         val = val.substr(1);
                     } else if (!in_group && !in_quote) {
                         ob.addNewItem(val.substr(0, orig_pos));
-                        val = val.substr(orig_pos + 2);
+                        val = val.substr(orig_pos + 1).strip();
                         pos = 0;
                     }
                     break;
