@@ -1,12 +1,12 @@
 <?php
 /**
- * Copyright 2012-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
  *
  * @category  Horde
- * @copyright 2012-2016 Horde LLC
+ * @copyright 2012-2017 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -16,7 +16,7 @@
  *
  * @author    Michael Slusarz <slusarz@horde.org>
  * @category  Horde
- * @copyright 2012-2016 Horde LLC
+ * @copyright 2012-2017 Horde LLC
  * @license   http://www.horde.org/licenses/gpl GPL
  * @package   IMP
  */
@@ -61,7 +61,9 @@ class IMP_Contents_View
         $tosave = array();
         foreach ($this->_contents->downloadAllList() as $val) {
             $mime = $this->_getRawDownloadPart($val);
-            if (!($name = $mime->getName(true))) {
+            if ($name = $mime->getName(true)) {
+                $name = preg_replace('/[\x00-\x1f]+/', '', $name);
+            } else {
                 $name = sprintf(_("part %s"), $val);
             }
             $tosave[] = array(
@@ -99,7 +101,7 @@ class IMP_Contents_View
             $data = Horde_Compress::factory('Zip')->compress(array(
                 array(
                     'data' => $mime->getContents(),
-                    'name' => $name
+                    'name' => preg_replace('/[\x00-\x1f]+/', '', $name)
                 )
             ), array(
                 'stream' => true
