@@ -1,6 +1,7 @@
 <form id="compose" name="compose" enctype="multipart/form-data" action="<?php echo $this->compose_link ?>" method="post" style="display:none">
  <?php echo $this->hiddenFieldTag('html', intval($this->rte && $this->compose_html)) ?>
  <?php echo $this->hiddenFieldTag('composeCache') ?>
+ <?php echo $this->hiddenFieldTag('composeHmac') ?>
  <?php echo $this->hiddenFieldTag('request_read_receipt', intval($this->read_receipt_set)) ?>
  <?php echo $this->hiddenFieldTag('user', $this->h($this->user)) ?>
 <?php if ($this->attach): ?>
@@ -65,6 +66,7 @@
       <?php echo $this->checkBoxTag('save_sent_mail', 1, false, array('class' => 'checkbox')) . _("Save in") ?>
       <span id="sent_mail_label"></span>
      </label>
+     <span class="iconImg horde-popdown" id="save_sent_mail_load"></span>
      <?php echo $this->hiddenFieldTag('save_sent_mail_mbox') ?>
     </div>
 <?php else: ?>
@@ -93,41 +95,45 @@
    </div>
 
    <table>
+<?php if (count($this->from_list) === 1): ?>
+    <?php echo $this->hiddenFieldTag('identity', $this->from_list[0]['val']) ?>
+<?php else: ?>
     <tr>
      <td class="label"><?php echo _("From") ?>:</td>
      <td>
       <select id="identity" name="identity">
-<?php foreach ($this->select_list as $v): ?>
+<?php foreach ($this->from_list as $v): ?>
        <?php echo $this->optionTag($v['val'], $this->h($v['label']), $v['sel']) ?>
 <?php endforeach; ?>
       </select>
-    </td>
+     </td>
     </tr>
+<?php endif; ?>
     <tr id="sendto">
      <td class="label">
       <span><?php echo _("To") ?>:</span>
      </td>
-     <td class="sendtextarea">
-      <?php echo $this->textAreaTag('to', null, array('size' => '75x1')) ?>
+     <td>
       <span id="to_loading_img" class="loadingImg" style="display:none"></span>
+      <?php echo $this->textAreaTag('to', null, array('size' => '75x1')) ?>
      </td>
     </tr>
     <tr id="sendcc" style="display:none">
      <td class="label">
       <span><?php echo _("Cc") ?>:</span>
      </td>
-     <td class="sendtextarea">
-      <?php echo $this->textAreaTag('cc', null, array('size' => '75x1')) ?>
+     <td>
       <span id="cc_loading_img" class="loadingImg" style="display:none"></span>
+      <?php echo $this->textAreaTag('cc', null, array('size' => '75x1')) ?>
      </td>
     </tr>
     <tr id="sendbcc" style="display:none">
      <td class="label">
       <span><?php echo _("Bcc") ?>:</span>
      </td>
-     <td class="sendtextarea">
-      <?php echo $this->textAreaTag('bcc', null, array('size' => '75x1')) ?>
+     <td>
       <span id="bcc_loading_img" class="loadingImg" style="display:none"></span>
+      <?php echo $this->textAreaTag('bcc', null, array('size' => '75x1')) ?>
      </td>
     </tr>
     <tr>
@@ -150,14 +156,14 @@
      </td>
      <td>
       <div id="atcdrop" style="display:none">
-       <?php echo _("Drop file here to attach.") ?>
+       <?php echo _("Drop file(s) here to attach.") ?>
       </div>
       <div id="atcdiv">
        <span id="upload_limit" style="display:none"><?php echo _("The attachment limit has been reached.") ?></span>
        <span id="upload_wait" style="display:none"></span>
        <span>
         <label id="compose_upload_add" for="upload"><?php echo _("Add Attachment") ?></label>
-        <?php echo $this->fileFieldTag('file_upload', array('id' => 'upload')) ?>
+        <?php echo $this->fileFieldTag('file_upload[]', array('id' => 'upload', 'multiple' => 'multiple')) ?>
        </span>
 <?php else: ?>
      <td></td>
@@ -200,5 +206,17 @@
   <div id="composeMessageParent">
    <textarea name="message" id="composeMessage" class="fixed"></textarea>
   </div>
+
+<?php if ($this->signature): ?>
+  <div id="signatureParent">
+   <div class="label">
+    <span id="signatureToggle" class="iconImg<?php if ($this->sigExpanded) echo ' signatureExpanded' ?>"></span>
+    <?php echo _("Signature")?>
+   </div>
+   <div id="signatureBorder"<?php if (!$this->sigExpanded) echo ' style="display:none"' ?>>
+    <textarea id="signature" name="signature" class="fixed"></textarea>
+   </div>
+  </div>
+<?php endif; ?>
  </div>
 </form>
